Module ast

Module ast 

Definitions of Koopa IR ASTs.

ASTs can represent the tree structures of the text form Koopa IR, and they will be built by the Koopa IR parser (Parser) during the parsing process.

Structs

Aggregate
Aggregate value.
ArrayType
Array type.
Ast
An abstract syntax tree (AST) of Koopa IR.
BinaryExpr
Binary expression.
Block
Basic block.
Branch
Branch.
End
End of file.
Error
Error.
FunCall
Function call.
FunDecl
Function declaration.
FunDef
Function definition.
FunType
Function type.
GetElementPointer
Element pointer calculation.
GetPointer
Pointer calculation.
GlobalDecl
Global memory declaration.
GlobalDef
Global symbol definition.
IntType
32-bit integer type.
IntVal
Integer literal.
Jump
Jump.
Load
Load.
MemDecl
Memory declaration.
PointerType
Pointer type.
Return
Return.
Store
Store.
SymbolDef
Symbol definition.
SymbolRef
Symbol reference.
UndefVal
Undefined value.
ZeroInit
Zero initializer.

Enums

AstKind
Kind of AST.

Type Aliases

AstBox
A boxed Koopa IR AST.